# GROBID TEI

This package uses GROBID to create annotated TEI documents from PDFs (see [example](https://github.com/CoLRev-Environment/colrev/blob/main/tests/data/WagnerLukyanenkoParEtAl2022.tei.xml)).

Running GROBID requires Docker.

## pdf-prep

This package can be added to a project using the following command:

```
colrev pdf-prep -a colrev.grobid_tei
```

## Links

- [GRBOBID](https://github.com/kermitt2/grobid)
